@@ -9,6 +9,7 @@ from bergen.messages import *
 from bergen.handlers import *
 from bergen.console import console
 from bergen.utils import *
+from bergen.legacy.utils import create_task
 
 
 class Actor:
@@ -71,7 +72,7 @@ class Actor:
                     message = await self.queue.get()
 
                     if isinstance(message, BouncedForwardedAssignMessage):
-                        task = asyncio.create_task(self.on_assign(message))
+                        task = create_task(self.on_assign(message))
                         task.add_done_callback(self.check_if_assignation_cancelled)
                         self.assignments[message.meta.reference] = task
 
@@ -124,11 +125,11 @@ class Actor:
     
     def check_if_assignation_cancelled(self, task: Task):
         if task.cancelled():
-            console.log(f"[yellow] Assignation {task.get_name()} Cancelled and is now Done")
+            console.log(f"[yellow] Assignation {task} Cancelled and is now Done")
         elif task.exception():
-            console.log(f"[red] Assignation {task.get_name()} Failed with {str(task.exception())}")
+            console.log(f"[red] Assignation {task} Failed with {str(task.exception())}")
         elif task.done():
-            console.log(f"[green] Assignation {task.get_name()} Succeeded and is now Done")
+            console.log(f"[green] Assignation {task} Succeeded and is now Done")
 
 
     async def on_assign(self, assign: BouncedForwardedAssignMessage):
