@@ -1,7 +1,7 @@
-import asyncio
 from bergen.debugging import DebugLevel
 from bergen.handlers import AssignHandler, ReserveHandler, ProvideHandler
 import contextvars
+from bergen.legacy.utils import get_running_loop
 
 loop_context = contextvars.ContextVar("loop_context", default=None)
 assign_handler_context  = contextvars.ContextVar('assign_handler', default=None)
@@ -27,7 +27,7 @@ def log(message: str, level: DebugLevel = DebugLevel.INFO):
         [Future]: Returns a future if currently running in an event loop
     """
     try:
-        event_loop = asyncio.get_running_loop()
+        event_loop = get_running_loop()
     except RuntimeError:
         loop = loop_context.get()
         loop.create_task(log_async(message, level))
