@@ -1,8 +1,5 @@
 from abc import abstractmethod
 from bergen.graphical import GraphicalBackend, has_webview
-
-from bergen.auths.types import HerreConfig
-
 from oauthlib.oauth2.rfc6749.clients.mobile_application import MobileApplicationClient
 from requests_oauthlib.oauth2_session import OAuth2Session
 from bergen.auths.base import BaseAuthBackend
@@ -13,7 +10,7 @@ logger = logging.getLogger(__name__)
 class ImplicitApplication(BaseAuthBackend):
 
 
-    def __init__(self, config: HerreConfig, parent=None, **kwargs) -> None:
+    def __init__(self, config, parent=None, **kwargs) -> None:
         super().__init__(config , **kwargs)  
         # TESTED, just redirecting to Google works in normal browsers
         # the token string appears in the url of the address bar
